@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 1109 2021-07-03 04:56:23Z Casey $
+# $Id: __init__.py 1146 2021-07-15 10:23:49Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $ (last)
-# $Date: 2021-07-03 12:56:23 +0800 (週六, 03 七月 2021) $
-# $Revision: 1109 $
+# $Author: Lavender $ (last)
+# $Date: 2021-07-15 18:23:49 +0800 (週四, 15 七月 2021) $
+# $Revision: 1146 $
 
 import os
 import sys
@@ -63,7 +63,10 @@ Runner.read_our_stdin = read_our_stdin
 def getBuildData(shPath, dataName):
     with open(shPath, 'r') as f:
         for line in f.readlines():
-            if ("%s=" % dataName in line) and ("#" not in line.lstrip()):
+            lineWithoutSpace = line.lstrip()
+            if lineWithoutSpace:
+                firstInLine = lineWithoutSpace[0]
+            if ("%s=" % dataName in line) and (firstInLine != "#" ):
                 index = line.index("=") + 1
                 return line[index:].replace('\r\n', '').strip()
     return None
@@ -164,7 +167,7 @@ def record(func, c, *args, **kwargs):
 
 # patch
 @opens
-def run(self, command, notRecord=False, **kwargs):
+def run(self, command, notRecord=False, hideStdout=False, **kwargs):
     """
     Execute a shell command on the remote end of this connection.
 
@@ -190,6 +193,9 @@ def run(self, command, notRecord=False, **kwargs):
 
     if six.PY2 and not kwargs.get("pty"):
         kwargs["hide"] = True
+        
+    if hideStdout:
+        kwargs["hide"] = True
 
     if not notRecord:
         c = "%s: %s" % (command, str(datetime.datetime.now().time()))
